tiled.readers.excel.ExcelReader
===============================

.. currentmodule:: tiled.readers.excel

.. autoclass:: ExcelReader

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ExcelReader.__init__
      ~ExcelReader.authenticated_as
      ~ExcelReader.from_file
      ~ExcelReader.get
      ~ExcelReader.items
      ~ExcelReader.keys
      ~ExcelReader.new_variation
      ~ExcelReader.register_query
      ~ExcelReader.register_query_lazy
      ~ExcelReader.search
      ~ExcelReader.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ExcelReader.access_policy
      ~ExcelReader.authenticated_identity
      ~ExcelReader.include_routers
      ~ExcelReader.items_indexer
      ~ExcelReader.keys_indexer
      ~ExcelReader.metadata
      ~ExcelReader.query_registry
      ~ExcelReader.values_indexer
   
   